;*************************************************************************
;*
;* NeuesProjekt (c) Kurzer
;*
;*************************************************************************
;*
;* Programname       : NeuesProjekt
;* Filename          : app_NeuesProjekt.pb
;* Filetype          : MainApp [MainApp, Formular, Include, Module, Data]
;* Programming lang. : Purebasic 5.60+
;* String-Format     : Unicode [Ascii, Unicode, Multi]
;* Platform          : Windows [Windows, Mac, Linux, Multi]
;* Processor         : x86 [x86, x64]
;* Compile as        : Exe [Exe, Console, DLL]
;* Compileroptions   : -
;* Version           : 1.xx
;* Date              : xx.xx.20xx
;* Autor             : Kurzer
;* -----------------------------------------------------------------------
;* DESCRIPTION:
;*
;* Programmtemplate: 1 Fenster und ein Settingsfenster
;* Nur unter PureBasic 5.60 oder hher lauffhig
;*
;* -----------------------------------------------------------------------
;* Changelog:
;* 1.xx - rel xx.xx.xx:
;*            Erste Version
;*
;*************************************************************************

;*************************************************************************
;- Compiler directives
;*************************************************************************
EnableExplicit

;*************************************************************************
;- Macros
;*************************************************************************

;*************************************************************************
;- Constants
;*************************************************************************
#Version								= "Version 1.xx - xx.xx.20xx"
#PrefsFile							= "NeuesProjekt.conf"
#ProgramName						= "NeuesProjekt" ; Wird als Verzeichnisname im Pfad der PrefsDatei genutzt, wenn InstallMode <> #InstallMode_Portable

; Objektnummern fr Fonts
#FontCourierNew					= 0

; Legt fest, wo das PrefsFile gespeichert werden soll
; Portable    = Im Programmverzeichnis selbst
; CurrentUser = Im Programmdaten-Verzeichnis des aktuellen Users (C:\Users\User\AppData\Roaming\ProgrammName\...)
; AllUsers    = Im Programmdaten-Verzeichnis aller User (C:\ProgramData\ProgrammName\...)
Enumeration 
	#InstallMode_Portable
	#InstallMode_CurrentUser
	#InstallMode_AllUsers
EndEnumeration
#InitialInstallMode			= #InstallMode_Portable ; Legt fest wo beim allerersten Start die Prefs-Datei angelegt wird

;*************************************************************************
;- Structures
;*************************************************************************
Structure WindowParams
	iWindow_PosX.i
	iWindow_PosY.i
	iWindow_Width.i
	iWindow_Height.i
EndStructure

Structure Application
	; Fenster-Attribute
	stWindow_Main.WindowParams
	stWindow_Settings.WindowParams
	; Sonstige Einstellungen die in das Prefsfile gespeichert werden
	iDemoCheckBox.i
	;
	iInstallationMode.i
	sPrefsFile.s
	iEvent.i
	iQuit.i
EndStructure

;*************************************************************************
;- Variables, Arrays, Linked Lists, Maps
;*************************************************************************
Global stApplication.Application

;*************************************************************************
;- Interfaces, Prototypes
;*************************************************************************

;*************************************************************************
;- Includefiles
;*************************************************************************
IncludeFile "dec_Declarations.pbi"																				; %DECLAREFILE
IncludeFile "gui_Windows.pbi"																							; %IGNOREFILE
IncludeFile "frm_Main.pbi"
IncludeFile "frm_Settings.pbi"
IncludeFile "mod_ModuleXYZ.pbi"

;-
;*************************************************************************
;- Procedures
;*************************************************************************
Procedure.i Application_Init()
	; +-----------------------------------------------------------------
	; |Description  : Initialisieren von Strukturen, Variablen, Images usw.
	; |Arguments    : -
	; |Results      : -
	; +-----------------------------------------------------------------
	Protected.s sPrefsPath
	
	;{ Ermitteln des Speicherorts der Prefsdatei
	
	; Programmverzeichnis "portable" (hier muss das Prefsfile aber auch existieren)
	sPrefsPath = GetPathPart(ProgramFilename())
	If FileSize(sPrefsPath + #PrefsFile) > -1
		stApplication\iInstallationMode = #InstallMode_Portable
	Else
		; Current Userdata-Verzeichnis
		sPrefsPath = GetUserDirectory(#PB_Directory_ProgramData) + #ProgramName + "\"
		If FileSize(sPrefsPath) = -2
			stApplication\iInstallationMode = #InstallMode_CurrentUser
		Else
			; All Userdata-Verzeichnis
			sPrefsPath = GetUserDirectory(#PB_Directory_AllUserData) + #ProgramName + "\"
			If FileSize(sPrefsPath) = -2
				stApplication\iInstallationMode = #InstallMode_AllUsers
			Else			
				; Wenn alles nicht gefunden wird, dann nutze #InitialInstallMode
				stApplication\iInstallationMode = #InitialInstallMode
				
				If stApplication\iInstallationMode = #InstallMode_Portable
					sPrefsPath = GetPathPart(ProgramFilename())
				ElseIf stApplication\iInstallationMode = #InstallMode_CurrentUser
					sPrefsPath = GetUserDirectory(#PB_Directory_ProgramData) + #ProgramName + "\"
				Else
					sPrefsPath = GetUserDirectory(#PB_Directory_AllUserData) + #ProgramName + "\"
				EndIf 
				; Ein noch nicht vorhandenes Verzeichnis anlegen
				If FileSize(sPrefsPath) = -1
					If CreateDirectory(sPrefsPath) = 0
						ProcedureReturn #False
					EndIf
				EndIf
			EndIf	
		EndIf
	EndIf	
	;}
	;{ Editorfont laden
	If LoadFont(#FontCourierNew, "Courier New", 10) = 0 : Goto ErrorExit : EndIf
	;}
	;{ Programmstruktur initialisieren
	stApplication\iQuit = #False
	stApplication\sPrefsFile = sPrefsPath + #PrefsFile

	stApplication\stWindow_Main\iWindow_PosX = 0
	stApplication\stWindow_Main\iWindow_PosY = 0
	stApplication\stWindow_Main\iWindow_Width = 510
	stApplication\stWindow_Main\iWindow_Height = 260
	
	stApplication\stWindow_Settings\iWindow_PosX = 0
	stApplication\stWindow_Settings\iWindow_PosY = 0
	stApplication\stWindow_Settings\iWindow_Width = 400
	stApplication\stWindow_Settings\iWindow_Height = 400
	;}
	ProcedureReturn #True
	
	ErrorExit:
	ProcedureReturn #False
	
EndProcedure
Procedure   Application_Free()
	; +-----------------------------------------------------------------
	; |Description  : Freigeben von Objekten, Speicher, Images usw.
	; |Arguments    : -
	; |Results      : -
	; +-----------------------------------------------------------------
	;{ Editorfont freigeben
	If IsFont(#FontCourierNew)
		FreeFont(#FontCourierNew)
	EndIf
	;}
	
EndProcedure

Procedure.i Application_LoadSettings()
	; +-----------------------------------------------------------------
	; |Description  : Ldt die Programmeinstellungen aus der Prefs-Datei und bertrgt die
	; |               Werte in die Applikationsstruktur
	; |Arguments    : -
	; |Results      : #False, wenn Fehler aufgetreten sind, sonst #True
	; +-----------------------------------------------------------------
	If OpenPreferences(stApplication\sPrefsFile) = 0
		If Application_SaveSettings() = #False : Goto ErrorExit : EndIf
	EndIf
	
	PreferenceGroup("Application")
	;{ Windowposition und Gre laden
	stApplication\stWindow_Main\iWindow_PosX = ReadPreferenceInteger("Window_Main_X", stApplication\stWindow_Main\iWindow_PosX)
	stApplication\stWindow_Main\iWindow_PosY = ReadPreferenceInteger("Window_Main_Y", stApplication\stWindow_Main\iWindow_PosY)
	stApplication\stWindow_Main\iWindow_Width = ReadPreferenceInteger("Window_Main_Width", stApplication\stWindow_Main\iWindow_Width)
	stApplication\stWindow_Main\iWindow_Height = ReadPreferenceInteger("Window_Main_Height", stApplication\stWindow_Main\iWindow_Height)
	
	stApplication\stWindow_Settings\iWindow_PosX = ReadPreferenceInteger("Window_Settings_X", stApplication\stWindow_Settings\iWindow_PosX)
	stApplication\stWindow_Settings\iWindow_PosY = ReadPreferenceInteger("Window_Settings_Y", stApplication\stWindow_Settings\iWindow_PosY)
	stApplication\stWindow_Settings\iWindow_Width = ReadPreferenceInteger("Window_Settings_Width", stApplication\stWindow_Settings\iWindow_Width)
	stApplication\stWindow_Settings\iWindow_Height = ReadPreferenceInteger("Window_Settings_Height", stApplication\stWindow_Settings\iWindow_Height)
	;}
	;{ Zustand der CheckBox laden
	stApplication\iDemoCheckBox = ReadPreferenceInteger("DemoCheckBox", stApplication\iDemoCheckBox)
	;}
	ClosePreferences()
	ProcedureReturn #True
	
	ErrorExit:
	ProcedureReturn #False
	
EndProcedure
Procedure.i Application_SaveSettings()
	; +-----------------------------------------------------------------
	; |Description  : Schreibt die Programmeinstellungen aus der Applikations-
	; |               struktur in die Prefs-Datei
	; |Arguments    : -
	; |Results      : #False, wenn Fehler aufgetreten sind, sonst #True
	; +-----------------------------------------------------------------
	If OpenPreferences(stApplication\sPrefsFile) = 0
		CreatePreferences(stApplication\sPrefsFile)
	EndIf
	If OpenPreferences(stApplication\sPrefsFile, #PB_Preference_GroupSeparator) = 0 : Goto ErrorExit : EndIf
	
	PreferenceGroup("Application")
	;{ Windowposition und Gre speichern
	WritePreferenceInteger("Window_Main_X", stApplication\stWindow_Main\iWindow_PosX)
	WritePreferenceInteger("Window_Main_Y", stApplication\stWindow_Main\iWindow_PosY)
	WritePreferenceInteger("Window_Main_Width", stApplication\stWindow_Main\iWindow_Width)
	WritePreferenceInteger("Window_Main_Height", stApplication\stWindow_Main\iWindow_Height)
	
	WritePreferenceInteger("Window_Settings_X", stApplication\stWindow_Settings\iWindow_PosX)
	WritePreferenceInteger("Window_Settings_Y", stApplication\stWindow_Settings\iWindow_PosY)
	WritePreferenceInteger("Window_Settings_Width", stApplication\stWindow_Settings\iWindow_Width)
	WritePreferenceInteger("Window_Settings_Height", stApplication\stWindow_Settings\iWindow_Height)
	;}
	;{ Zustand der CheckBox speichern
	WritePreferenceInteger("DemoCheckBox", stApplication\iDemoCheckBox)
	;}
	ClosePreferences()
	ProcedureReturn #True
	
	ErrorExit:	
	ProcedureReturn #False
	
EndProcedure
;-
;*************************************************************************
;- Application Library-Init
;*************************************************************************
; Z.B. InitNetwork

;*************************************************************************
;- Application Main
;*************************************************************************
If Application_Init() = #True
	If Application_LoadSettings() = #True
		Main_Main()
	EndIf
EndIf

;*************************************************************************
;- Application End
;*************************************************************************
Application_Free()
End

;*************************************************************************
;- Data Section
;*************************************************************************
DataSection

EndDataSection

; IDE Options = PureBasic 5.61 (Windows - x64)
; Folding = -----
; EnableXP
; CompileSourceDirectory
; EnableCompileCount = 0
; EnableBuildCount = 0
; EnableExeConstant
; EnableUnicode