;*************************************************************************
;*
;* NeuesProjekt (c) Kurzer
;*
;*************************************************************************
;*
;* Programname       : NeuesProjekt
;* Applicationfile   : app_NeuesProjekt.pb
;* Filename          : frm_Main.pbi
;* Filetype          : Formular [MainApp, Formular, Include, Module, Data]
;* -----------------------------------------------------------------------
;* DESCRIPTION:
;*
;* ...
;*
;*************************************************************************

;*************************************************************************
;- Constants
;*************************************************************************
#Window_Main_Title      = "Template"
#Window_Main_MinX				= 200
#Window_Main_MaxX				= 800
#Window_Main_MinY				= 200
#Window_Main_MaxY				= 600

; Objektnummern fr Men, Toolbar und Statusbar
#Menu_Window_Main				= 0
#Toolbar_Window_Main		= 0
#Statusbar_Window_Main	= 0

; Feld-Konstanten fr die Statusbar
#Statusbar_Text_Ready		= "Dies ist die Statusbar"

; Item-Konstanten fr Men und Toolbar (diese mssen in einer Enumeration liegen, da beides als Menu-Event geliefert wird)
Enumeration
  #Menu_Window_Main_Open
  #Menu_Window_Main_Save
  #Menu_Window_Main_Settings
  #Toolbar_Window_Main_New
  #Toolbar_Window_Main_Open
  #Toolbar_Window_Main_Save
EndEnumeration

Enumeration
	#Image_Main_Menu_Settings
	#LastImage													; <- Ende-Markierung fr FreeImage()
EndEnumeration

;*************************************************************************
;- GUI-Procedures
;*************************************************************************
Procedure   Main_InitGUI()
	; +-----------------------------------------------------------------
	; |Description  : Initialisieren des Fensters, der Gadgets und Objekte
	; |Arguments    : -
	; |Results      : -
	; |Remarks      : -
	; +-----------------------------------------------------------------
	;{ Fensterattribute setzen
	SmartWindowRefresh(Window_Main, #True) 
	SetWindowTitle(Window_Main, #Window_Main_Title + " - " + #Version)
	WindowBounds(Window_Main, #Window_Main_MinX, #Window_Main_MinY, #Window_Main_MaxX, #Window_Main_MaxY)
	;}
	;{ Images fr Mens erzeugen
	CatchImage(#Image_Main_Menu_Settings, ?Image_Settings)
	;}
	;{ Men erzeugen 
	; Wenn ein Men benutzt wird, muss in PureForm ein Dummy-Men mit einem Eintrag erzeugt werden, da sonst die Windowhhe nicht passt
	If CreateImageMenu(#Menu_Window_Main, WindowID(Window_Main)) <> 0
		MenuTitle("Datei")
		MenuItem(#Menu_Window_Main_Open, "ffnen" + #TAB$ + "[STRG + O]")
		AddKeyboardShortcut(Window_Main, #PB_Shortcut_Control | #PB_Shortcut_O, #Menu_Window_Main_Open)
		MenuItem(#Menu_Window_Main_Save, "Speichern")
		MenuTitle("Einstellungen")
		MenuItem(#Menu_Window_Main_Settings, "Einstellungen" + #TAB$ + "[STRG + E]", ImageID(#Image_Main_Menu_Settings))
    AddKeyboardShortcut(Window_Main, #PB_Shortcut_Control | #PB_Shortcut_E, #Menu_Window_Main_Settings)
	EndIf
	;}
	;{ Toolbar erzeugen
	; Wenn eine Toolbar benutzt wird, muss in PureForm eine Dummy-Toolbar mit einem Eintrag erzeugt werden, da sonst die Windowhhe nicht passt
	If CreateToolBar(#Toolbar_Window_Main, WindowID(Window_Main)) <> 0
		ToolBarStandardButton(#Toolbar_Window_Main_New, #PB_ToolBarIcon_New)
		ToolBarStandardButton(#Toolbar_Window_Main_Open, #PB_ToolBarIcon_Open)
		ToolBarStandardButton(#Toolbar_Window_Main_Save, #PB_ToolBarIcon_Save)
	EndIf
	;}
	;{ Statusbar erzeugen
	; Wenn eine Statusbar benutzt wird, muss in PureForm eine Dummy-Statusbar erzeugt werden, da sonst die Windowhhe nicht passt
	If CreateStatusBar(#Statusbar_Window_Main, WindowID(Window_Main)) <> 0
		AddStatusBarField(4096)
		StatusBarText(#Statusbar_Window_Main, 0, #Statusbar_Text_Ready)
	EndIf
	;}
	;{ Font fr Editorgadget	setzen
	SetGadgetFont(Window_Main_Editor_Dummy, FontID(#FontCourierNew))
	SetGadgetText(Window_Main_Editor_Dummy, "Dies ist ein Editorgadget")
	;}
	;{ Fensterposition und Gre restaurieren
	Main_RestoreGUI()
	;}
	HideWindow(Window_Main, #False)
	
EndProcedure
Procedure   Main_FreeGUI()
	; +-----------------------------------------------------------------
	; |Description  : Freigeben von Gadgets und Objekten
	; |Arguments    : -
	; |Results      : -
	; |Remarks      : -
	; +-----------------------------------------------------------------
	Protected.i i
	;{ Fensterposition und Gre speichern (immer als erste Zeile)
	Main_StoreGUI()
	;}
	;{ Fensterobjekte entfernen
	RemoveKeyboardShortcut(Window_Main, #PB_Shortcut_All)
	FreeMenu(#Menu_Window_Main) 
	FreeToolBar(#Toolbar_Window_Main)
	; Alle Gadgets werden automatisch freigegeben, wenn das Fenster geschlossen wird.
	;}
	;{ Images freigeben
	For i = 0 To #LastImage - 1
		If IsImage(i) <> 0
			FreeImage(i)
		EndIf
	Next i
	;}
	
EndProcedure
Procedure   Main_StoreGUI()
	; +-----------------------------------------------------------------
	; |Description  : Speichern der Gadget- und Fensterzustnde in der Applikations- und Settingsstruktur
	; |Arguments    : -
	; |Results      : -
	; |Remarks      : Wird automatisch von FreeGUI oder dem WindowHandler() aufgerufen
	; +-----------------------------------------------------------------
	If IsWindow(Window_Main) <> 0
		;{ Windowposition und Gre speichern
		stApplication\stWindow_Main\iWindow_PosX = WindowX(Window_Main)
		stApplication\stWindow_Main\iWindow_PosY = WindowY(Window_Main)
		stApplication\stWindow_Main\iWindow_Width = WindowWidth(Window_Main)
		stApplication\stWindow_Main\iWindow_Height = WindowHeight(Window_Main)
		;}
	EndIf
	
EndProcedure
Procedure   Main_RestoreGUI()
	; +-----------------------------------------------------------------
	; |Description  : Lesen der Gadget- und Fensterzustnde aus der Applikations- und Settingsstruktur
	; |Arguments    : -
	; |Results      : -
	; |Remarks      : Wird automatisch von InitGUI aufgerufen
	; +-----------------------------------------------------------------
	If IsWindow(Window_Main) <> 0
		;{ Windowposition und Gre setzen
		ResizeWindow(Window_Main, stApplication\stWindow_Main\iWindow_PosX, stApplication\stWindow_Main\iWindow_PosY, stApplication\stWindow_Main\iWindow_Width, stApplication\stWindow_Main\iWindow_Height)
		;}
		;{ Event_Main_WindowHandler() anspringen, um die Gadgets zu positionieren
		PostEvent(#PB_Event_SizeWindow, Window_Main, 0)
		;}
	EndIf
	
EndProcedure
;-
Procedure   Main_RegisterEvents()
	; +-----------------------------------------------------------------
	; |Description  : Ordnet den Gadgets, Mens usw. die Eventprozeduren zu
	; |Arguments    : -
	; |Results      : -
	; |Remarks      : -
	; +-----------------------------------------------------------------
	BindMenuEvent(#Menu_Window_Main, #Menu_Window_Main_Open, @Event_Main_Menu_Open())
	BindMenuEvent(#Menu_Window_Main, #Menu_Window_Main_Settings, @Event_Main_Menu_Settings())
	BindMenuEvent(#Menu_Window_Main, #Toolbar_Window_Main_Open, @Event_Main_Menu_Open())
	
	BindGadgetEvent(Window_Main_Button_Exit, @Event_Main_Button_Exit(), #PB_EventType_LeftClick)
	
	BindEvent(#PB_Event_SizeWindow, @Event_Main_WindowHandler(), Window_Main)
	BindEvent(#PB_Event_MoveWindow, @Event_Main_WindowHandler(), Window_Main)
	BindEvent(#PB_Event_CloseWindow, @Event_Main_Button_Exit(), Window_Main)
	
EndProcedure
Procedure   Main_UnregisterEvents()
	; +-----------------------------------------------------------------
	; |Description  : Hebt die Zuordnung der Eventprozeduren auf
	; |Arguments    : -
	; |Results      : -
	; |Remarks      : -
	; +-----------------------------------------------------------------
	UnbindMenuEvent(#Menu_Window_Main, #Menu_Window_Main_Open, @Event_Main_Menu_Open())
	UnbindMenuEvent(#Menu_Window_Main, #Menu_Window_Main_Settings, @Event_Main_Menu_Settings())
	UnbindMenuEvent(#Menu_Window_Main, #Toolbar_Window_Main_Open, @Event_Main_Menu_Open())
	
	UnbindGadgetEvent(Window_Main_Button_Exit, @Event_Main_Button_Exit(), #PB_EventType_LeftClick)
	
	UnbindEvent(#PB_Event_SizeWindow, @Event_Main_WindowHandler(), Window_Main)
	UnbindEvent(#PB_Event_MoveWindow, @Event_Main_WindowHandler(), Window_Main)
	UnbindEvent(#PB_Event_CloseWindow, @Event_Main_Button_Exit(), Window_Main)
	
EndProcedure
;-
Procedure.i Main_OpenWindow()
	; +-----------------------------------------------------------------
	; |Description  : ffnet das Programmfenster
	; |Arguments    : -
	; |Results      : #False, wenn das Fenster bereits offen war, sonst #True
	; |Remarks      : -
	; +-----------------------------------------------------------------
	If IsWindow(Window_Main) = 0
		OpenWindow_Window_Main()
	EndIf 
	
	If IsWindow(Window_Main) <> 0
		Main_InitGUI()
		Main_RegisterEvents()
		
		ProcedureReturn #True
	Else	
		ProcedureReturn #False
	EndIf
	
EndProcedure
Procedure.i Main_CloseWindow()
	; +-----------------------------------------------------------------
	; |Description  : Schliet das Programmfenster
	; |Arguments    : -
	; |Results      : #False, wenn Fehler aufgetreten sind, sonst #True
	; |Remarks      : -
	; +-----------------------------------------------------------------
	If IsWindow(Window_Main) <> 0
		Main_UnregisterEvents()
		Main_FreeGUI()
		
		CloseWindow(Window_Main)
		; WORKAROUND fr http://www.purebasic.fr/english/viewtopic.php?f=4&t=66808
		Window_Main = 0
		Window_Settings = 0
		
		ProcedureReturn #True
	Else	
		ProcedureReturn #False
	EndIf
	
EndProcedure
;-
;*************************************************************************
;- Event-Procedures
;*************************************************************************
Procedure   Event_Main_WindowHandler()
	; +-----------------------------------------------------------------
	; |Description  : Bearbeitung von Window-Events
	; |Arguments    : -
	; |Results      : -
	; |Remarks      : -
	; +-----------------------------------------------------------------
	Protected.i iWindowWidth, iWindowHeight, iEvent
	
	iEvent = Event()
	
	If iEvent = #PB_Event_SizeWindow
		iWindowWidth  = WindowWidth(Window_Main, #PB_Window_InnerCoordinate)
		iWindowHeight = WindowHeight(Window_Main, #PB_Window_InnerCoordinate)
		
		ResizeGadget(Window_Main_Editor_Dummy, #PB_Ignore, #PB_Ignore, iWindowWidth - 20, iWindowHeight - 130)
		ResizeGadget(Window_Main_Button_Exit, iWindowWidth - 110, iWindowHeight - 90, #PB_Ignore, #PB_Ignore)
	EndIf 
	
	Main_StoreGUI()
	
EndProcedure
Procedure   Event_Main_Menu_Open()
	; +-----------------------------------------------------------------
	; |Description  : Bearbeitung eines Men-Events
	; |Arguments    : -
	; |Results      : -
	; |Remarks      : -
	; +-----------------------------------------------------------------
	MessageRequester("Men oder Toolbar", "Menpunkt oder Toolbar-Button 'ffnen' wurde gewhlt/geklickt!")
	
EndProcedure
Procedure   Event_Main_Menu_Settings()
	; +-----------------------------------------------------------------
	; |Description  : Bearbeitung des #PB_EventType_LeftClick Events
	; |Arguments    : -
	; |Results      : -
	; |Remarks      : -
	; +-----------------------------------------------------------------
	Settings_OpenWindow()
	
EndProcedure
Procedure   Event_Main_Button_Exit()
	; +-----------------------------------------------------------------
	; |Description  : Bearbeitung des #PB_EventType_LeftClick Events
	; |Arguments    : -
	; |Results      : -
	; |Remarks      : -
	; +-----------------------------------------------------------------
	stApplication\iQuit = #True	
	
EndProcedure
;-
;*************************************************************************
;- XYZ-Procedures
;*************************************************************************

;-
;*************************************************************************
;- Main (Eventloop)
;*************************************************************************
Procedure   Main_Main()
	; +-----------------------------------------------------------------
	; |Description  : Einsprungprozedur, enthlt den Messageloop des Programms
	; |Arguments    : -
	; |Results      : -
	; |Remarks      : -
	; +-----------------------------------------------------------------
	If Main_OpenWindow() = #True
		
		;*************************************************************************
		;* Eventloop
		;*************************************************************************
		Repeat
			stApplication\iEvent = WaitWindowEvent()
		Until stApplication\iQuit = #True
		
		;*************************************************************************
		;* Exit code
		;*************************************************************************
		Settings_CloseWindow()
		Main_CloseWindow()
		
	Else
		MessageRequester("Fehler", "Das Programmfenster konnte nicht geffnet werden.")
	EndIf
	
EndProcedure

;*************************************************************************
;- Data Section
;*************************************************************************
DataSection
	; Men-Images
	Image_Settings:
  IncludeBinary "Daten\Settingsicon.ico"
EndDataSection
; IDE Options = PureBasic 5.61 (Windows - x64)
; CursorPosition = 288
; FirstLine = 288
; Folding = -------
; EnableXP
; CompileSourceDirectory
; EnableCompileCount = 0
; EnableBuildCount = 0
; EnableExeConstant
; EnableUnicode