﻿;*************************************************************************
;*
;* NeuesProjekt (c) Kurzer
;*
;*************************************************************************
;*
;* Programname       : NeuesProjekt
;* Applicationfile   : app_NeuesProjekt.pb
;* Filename          : frm_Settings.pbi
;* Filetype          : Formular [MainApp, Formular, Include, Module, Data]
;* -----------------------------------------------------------------------
;* DESCRIPTION:
;*
;* ...
;*
;*************************************************************************

;*************************************************************************
;- Constants
;*************************************************************************
#Window_Settings_Title  = "Template - Einstellungen"
#Window_Settings_MinX		= 200
#Window_Settings_MaxX		= 400
#Window_Settings_MinY		= 200
#Window_Settings_MaxY		= 400

;*************************************************************************
;- GUI-Procedures
;*************************************************************************
Procedure   Settings_InitGUI()
	; +-----------------------------------------------------------------
	; |Description  : Initialisieren des Fensters, der Gadgets und Objekte
	; |Arguments    : -
	; |Results      : -
	; |Remarks      : -
	; +-----------------------------------------------------------------
	;{ Fensterattribute setzen
	SmartWindowRefresh(Window_Settings, #True) 
	SetWindowTitle(Window_Settings, #Window_Settings_Title)
	WindowBounds(Window_Settings, #Window_Settings_MinX, #Window_Settings_MinY, #Window_Settings_MaxX, #Window_Settings_MaxY)
	;}
	;{ Das Hauptfenster sperren
	DisableWindow(Window_Main, #True)
	;}
	;{ Fensterposition und Größe restaurieren
	Settings_RestoreGUI()
	HideWindow(Window_Settings, #False)
	;}

EndProcedure
Procedure   Settings_FreeGUI()
	; +-----------------------------------------------------------------
	; |Description  : Freigeben von Gadgets und Objekten
	; |Arguments    : -
	; |Results      : -
	; |Remarks      : -
	; +-----------------------------------------------------------------
	;{ Fensterposition und Größe speichern (immer als erste Zeile)
	Settings_StoreGUI()
	;}	
	;{ Das Hauptfenster entsperren
	DisableWindow(Window_Main, #False)
	;}
	
EndProcedure
Procedure   Settings_StoreGUI()
	; +-----------------------------------------------------------------
	; |Description  : Speichern der Gadget- und Fensterzustände in der Applikations- und Settingsstruktur
	; |Arguments    : -
	; |Results      : -
	; |Remarks      : Wird automatisch von FreeGUI oder dem WindowHandler() aufgerufen
	; +-----------------------------------------------------------------
	If IsWindow(Window_Settings) <> 0
		;{ Windowposition und Größe speichern
		stApplication\stWindow_Settings\iWindow_PosX = WindowX(Window_Settings)
		stApplication\stWindow_Settings\iWindow_PosY = WindowY(Window_Settings)
		stApplication\stWindow_Settings\iWindow_Width = WindowWidth(Window_Settings)
		stApplication\stWindow_Settings\iWindow_Height = WindowHeight(Window_Settings)
		;}
		;{ Zustand der CheckBox speichern
		stApplication\iDemoCheckBox = GetGadgetState(Window_Settings_CheckBox_DemoCB)
		;}
	EndIf
		
EndProcedure
Procedure   Settings_RestoreGUI()
	; +-----------------------------------------------------------------
	; |Description  : Lesen der Gadget- und Fensterzustände aus der Applikations- und Settingsstruktur
	; |Arguments    : -
	; |Results      : -
	; |Remarks      : Wird automatisch von InitGUI aufgerufen
	; +-----------------------------------------------------------------
	If IsWindow(Window_Settings) <> 0
		;{ Windowposition und Größe setzen
		ResizeWindow(Window_Settings, stApplication\stWindow_Settings\iWindow_PosX, stApplication\stWindow_Settings\iWindow_PosY, stApplication\stWindow_Settings\iWindow_Width, stApplication\stWindow_Settings\iWindow_Height)
		;}
		;{ Zustand der CheckBox wiederherstellen
		SetGadgetState(Window_Settings_CheckBox_DemoCB, stApplication\iDemoCheckBox)
		;}
		;{ Event_Settings_WindowHandler() anspringen, um die Gadgets zu positionieren
		PostEvent(#PB_Event_SizeWindow, Window_Settings, 0)
		;}
	EndIf
	
EndProcedure
;-
Procedure   Settings_RegisterEvents()
	; +-----------------------------------------------------------------
	; |Description  : Ordnet den Gadgets, Menüs usw. die Eventprozeduren zu
	; |Arguments    : -
	; |Results      : -
	; |Remarks      : -
	; +-----------------------------------------------------------------
	BindGadgetEvent(Window_Settings_Button_Save, @Event_Settings_Button_Save(), #PB_EventType_LeftClick)
	BindGadgetEvent(Window_Settings_Button_Exit, @Event_Settings_CloseWindow(), #PB_EventType_LeftClick)
	
	BindEvent(#PB_Event_SizeWindow, @Event_Settings_WindowHandler(), Window_Settings)
	BindEvent(#PB_Event_MoveWindow, @Event_Settings_WindowHandler(), Window_Settings)
	BindEvent(#PB_Event_CloseWindow, @Event_Settings_CloseWindow(), Window_Settings)
	
EndProcedure
Procedure   Settings_UnregisterEvents()
	; +-----------------------------------------------------------------
	; |Description  : Hebt die Zuordnung der Eventprozeduren auf
	; |Arguments    : -
	; |Results      : -
	; |Remarks      : -
	; +-----------------------------------------------------------------
	UnbindGadgetEvent(Window_Settings_Button_Save, @Event_Settings_Button_Save(), #PB_EventType_LeftClick)
	UnbindGadgetEvent(Window_Settings_Button_Exit, @Event_Settings_CloseWindow(), #PB_EventType_LeftClick)
	
	UnbindEvent(#PB_Event_SizeWindow, @Event_Settings_WindowHandler(), Window_Settings)
	UnbindEvent(#PB_Event_MoveWindow, @Event_Settings_WindowHandler(), Window_Settings)
	UnbindEvent(#PB_Event_CloseWindow, @Event_Settings_CloseWindow(), Window_Settings)
	
EndProcedure
;-
Procedure.i Settings_OpenWindow()
	; +-----------------------------------------------------------------
	; |Description  : Öffnet das Einstellungsfenster
	; |Arguments    : -
	; |Results      : #False, wenn Fehler aufgetreten sind, sonst #True
	; |Remarks      : -
	; +-----------------------------------------------------------------
	If IsWindow(Window_Settings) = 0
		OpenWindow_Window_Settings()
	EndIf 
	
	If IsWindow(Window_Settings) <> 0
		Settings_InitGUI()
		Settings_RegisterEvents()
		
		ProcedureReturn #True
	Else	
		ProcedureReturn #False
	EndIf
	
EndProcedure
Procedure.i Settings_CloseWindow()
	; +-----------------------------------------------------------------
	; |Description  : Schließt das Einstellungsfenster
	; |Arguments    : -
	; |Results      : #False, wenn Fehler aufgetreten sind, sonst #True
	; |Remarks      : -
	; +-----------------------------------------------------------------
	If IsWindow(Window_Settings) <> 0
		Settings_UnregisterEvents()
		Settings_FreeGUI()
		
		CloseWindow(Window_Settings)
		; WORKAROUND für http://www.purebasic.fr/english/viewtopic.php?f=4&t=66808
		Window_Settings = 0
		
  	ProcedureReturn #True
	Else	
		ProcedureReturn #False
	EndIf
	
EndProcedure
;-
;*************************************************************************
;- Event-Procedures
;*************************************************************************
Procedure   Event_Settings_WindowHandler()
	; +-----------------------------------------------------------------
	; |Description  : Bearbeitung von Window-Events
	; |Arguments    : -
	; |Results      : -
	; |Remarks      : -
	; +-----------------------------------------------------------------
	Protected.i iWindowWidth, iWindowHeight, iEvent
	
	iEvent = Event()
	
	If iEvent = #PB_Event_SizeWindow
		iWindowWidth  = WindowWidth(Window_Settings, #PB_Window_InnerCoordinate)
		iWindowHeight = WindowHeight(Window_Settings, #PB_Window_InnerCoordinate)
		
	 	ResizeGadget(Window_Settings_Frame3D_Main, #PB_Ignore, #PB_Ignore, iWindowWidth - 10, iWindowHeight - 55)
	 	ResizeGadget(Window_Settings_Button_Save, #PB_Ignore, iWindowHeight - 40, #PB_Ignore, #PB_Ignore)
	 	ResizeGadget(Window_Settings_Button_Exit, iWindowWidth - 95, iWindowHeight - 40, #PB_Ignore, #PB_Ignore)
	EndIf 
	
 	Settings_StoreGUI()
	
EndProcedure
Procedure   Event_Settings_CloseWindow()
	; +-----------------------------------------------------------------
	; |Description  : Bearbeitung des #PB_EventType_LeftClick Events
	; |Arguments    : -
	; |Results      : -
	; |Remarks      : -
	; +-----------------------------------------------------------------
	Settings_CloseWindow()
	
EndProcedure
Procedure   Event_Settings_Button_Save()
	; +-----------------------------------------------------------------
	; |Description  : Bearbeitung des #PB_EventType_LeftClick Events
	; |Arguments    : -
	; |Results      : -
	; |Remarks      : -
	; +-----------------------------------------------------------------
	Main_StoreGUI()
	Settings_StoreGUI()

	If Application_SaveSettings() = #False
		MessageRequester("Fehler", "Die Prefs-Datei konnte nicht geschrieben werden." + #CR$ +
		                           "Die Einstellungen wurden nicht gespeichert!" + #CR$ + #CR$ + 
		                           "(" + stApplication\sPrefsFile +")", #MB_ICONERROR)
	EndIf
	
	Settings_CloseWindow()
	
EndProcedure
;-
;*************************************************************************
;- XYZ Procedures
;*************************************************************************

;*************************************************************************
;- Data Section
;*************************************************************************
DataSection
	
EndDataSection
; IDE Options = PureBasic 5.61 (Windows - x64)
; CursorPosition = 223
; FirstLine = 174
; Folding = Rmz-t
; EnableXP
; CompileSourceDirectory
; EnableCompileCount = 0
; EnableBuildCount = 0
; EnableExeConstant